@@ -36,15 +36,16 @@ class Base64UnitTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
     void test1_data();
     void test1();
     void test2_data();
     void test2();
+
 private:
-    QCA::Initializer* m_init;
+    QCA::Initializer *m_init;
 };
 
 void Base64UnitTest::initTestCase()
@@ -63,41 +64,40 @@ void Base64UnitTest::test1_data()
     QTest::addColumn<QString>("encoded");
 
     // these are from the Botan test suite. Note that these are hex encoded!
-    QTest::newRow("31") << QString("31") << QString("4d513d3d");
-    QTest::newRow("235c91") << QString("235c91") << QString("49317952");
-    QTest::newRow("414") << QString("4142634452313236")
-			 << QString("51554a6a524649784d6a593d");
-    QTest::newRow("241") << QString("241bb300a3989a620659")
-			 << QString("4a42757a414b4f596d6d494757513d3d");
-    QTest::newRow("313") << QString("31323537374343666671333435337836")
-			 << QString("4d5449314e7a644451325a6d63544d304e544e344e673d3d");
-    QTest::newRow("60e") << QString("60e8e5ebb1a5eac95a01ec7f8796b2dce471")
-			 << QString("594f6a6c3637476c36736c614165782f68356179334f5278");
-    QTest::newRow("3134") << QString("31346d354f33313333372c31274d754e7354307050346231333a29")
-			  << QString("4d5452744e55387a4d544d7a4e7977784a303131546e4e554d4842514e4749784d7a6f70");
+    QTest::newRow("31") << QStringLiteral("31") << QStringLiteral("4d513d3d");
+    QTest::newRow("235c91") << QStringLiteral("235c91") << QStringLiteral("49317952");
+    QTest::newRow("414") << QStringLiteral("4142634452313236") << QStringLiteral("51554a6a524649784d6a593d");
+    QTest::newRow("241") << QStringLiteral("241bb300a3989a620659")
+                         << QStringLiteral("4a42757a414b4f596d6d494757513d3d");
+    QTest::newRow("313") << QStringLiteral("31323537374343666671333435337836")
+                         << QStringLiteral("4d5449314e7a644451325a6d63544d304e544e344e673d3d");
+    QTest::newRow("60e") << QStringLiteral("60e8e5ebb1a5eac95a01ec7f8796b2dce471")
+                         << QStringLiteral("594f6a6c3637476c36736c614165782f68356179334f5278");
+    QTest::newRow("3134") << QStringLiteral("31346d354f33313333372c31274d754e7354307050346231333a29")
+                          << QStringLiteral("4d5452744e55387a4d544d7a4e7977784a303131546e4e554d4842514e4749784d7a6f70");
 }
 
-
 void Base64UnitTest::test2_data()
 {
     QTest::addColumn<QString>("raw");
     QTest::addColumn<QString>("encoded");
 
     // these are from Python 2.3's tests for base64
-    QTest::newRow("www.python.org") << QString("www.python.org")
-				    << QString("d3d3LnB5dGhvbi5vcmc=");
-    QTest::newRow("a") << QString("a") << QString("YQ==");
-    QTest::newRow("ab") << QString("ab") << QString("YWI=");
-    QTest::newRow("abc") << QString("abc") << QString("YWJj");
-    QTest::newRow("empty") << QString("") << QString("");
-    QTest::newRow("a-Z") << QString("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#0^&*();:<>,. []{}")
-			 << QString("YWJjZGVmZ2hpamtsbW5vcHFyc3R1dnd4eXpBQkNERUZHSElKS0xNTk9QUVJTVFVWV1hZWjAxMjM0NTY3ODkhQCMwXiYqKCk7Ojw+LC4gW117fQ==");
+    QTest::newRow("www.python.org") << QStringLiteral("www.python.org") << QStringLiteral("d3d3LnB5dGhvbi5vcmc=");
+    QTest::newRow("a") << QStringLiteral("a") << QStringLiteral("YQ==");
+    QTest::newRow("ab") << QStringLiteral("ab") << QStringLiteral("YWI=");
+    QTest::newRow("abc") << QStringLiteral("abc") << QStringLiteral("YWJj");
+    QTest::newRow("empty") << QString(QLatin1String("")) << QString(QLatin1String(""));
+    QTest::newRow("a-Z") << QStringLiteral(
+                                "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#0^&*();:<>,. []{}")
+                         << QStringLiteral(
+                                "YWJjZGVmZ2hpamtsbW5vcHFyc3R1dnd4eXpBQkNERUZHSElKS0xNTk9QUVJTVFVWV1hZWjAxMjM0NTY3ODkhQC"
+                                "MwXiYqKCk7Ojw+LC4gW117fQ==");
 
     // these are generated by Python 2.3. I removed the trailing newline
-    QTest::newRow("31") << QString("31") << QString("MzE=");
-    QTest::newRow("QCA_2.0") << QString("QCA_2.0") << QString("UUNBXzIuMA==");
-    QTest::newRow("j-0") << QString("jh/*-*/*-/4983589230")
-			 << QString("amgvKi0qLyotLzQ5ODM1ODkyMzA=");
+    QTest::newRow("31") << QStringLiteral("31") << QStringLiteral("MzE=");
+    QTest::newRow("QCA_2.0") << QStringLiteral("QCA_2.0") << QStringLiteral("UUNBXzIuMA==");
+    QTest::newRow("j-0") << QStringLiteral("jh/*-*/*-/4983589230") << QStringLiteral("amgvKi0qLyotLzQ5ODM1ODkyMzA=");
 }
 
 void Base64UnitTest::test1()
@@ -118,11 +118,11 @@ void Base64UnitTest::test2()
     QFETCH(QString, raw);
     QFETCH(QString, encoded);
 
-    QCOMPARE( base64Object.encodeString(raw), encoded );
-    QCOMPARE( base64Object.decodeString(encoded), raw );
+    QCOMPARE(base64Object.encodeString(raw), encoded);
+    QCOMPARE(base64Object.decodeString(encoded), raw);
 
-    QCOMPARE( QCA::arrayToBase64(raw.toUtf8()), encoded );
-    QCOMPARE( QLatin1String(QCA::base64ToArray(encoded)), raw );
+    QCOMPARE(QCA::arrayToBase64(raw.toUtf8()), encoded);
+    QCOMPARE(QLatin1String(QCA::base64ToArray(encoded)), raw);
 }
 
 QTEST_MAIN(Base64UnitTest)
